###Replication code for paper "Was the Delimitation Commission Unfair to Muslims?" by Francesca R. Jensenius, which appeared in Studies in Indian Politics, 2013, vol. 1, no. 2, pp. 213–229

#Packages used
library(foreign)
library(xtable)
library(exactRankTests)
library(Matching)

setwd("") #Needs to be set to the directory the replication data is saved to
dta1971<-read.csv("ReplicationDta.csv") 

#Creating variable excluding ST-reserved constituencies
dta1971$AC_type_noST<-ifelse(dta1971$AC_type_1976 =="ST", NA, as.character(dta1971$AC_type_1976))
dta1971<-dta1971[complete.cases(dta1971$AC_type_noST),]

#Creating Percentage of Muslims of total population and of non-SC population
dta1971$muslims_percent<-100*((dta1971$muslim_m_est+dta1971$muslim_f_est)/dta1971$Tot_pop_true)
dta1971$muslims_percent_non_SC<-100*((dta1971$muslim_m_est+dta1971$muslim_f_est)/(dta1971$Tot_pop_true-dta1971$SC_pop_true))


####Figure 1 was reproduced from the Sachar Committee Report

####Table 1 -- summary statistics

states<-unique(dta1971$State_name_1976)
states<-states[order(states)]

mytable<-as.data.frame(matrix(nrow=length(states), ncol=5))
for (i in 1:length(states)){
mytable[i,1]<-dim(dta1971[dta1971$State_name_1976==states[i] & !is.na(dta1971$muslims_percent),])[1]
mytable[i,2]<-round(min(dta1971$muslims_percent[dta1971$State_name_1976==states[i] & !is.na(dta1971$muslims_percent)]),2)
mytable[i,3]<-round(max(dta1971$muslims_percent[dta1971$State_name_1976==states[i] & !is.na(dta1971$muslims_percent)]),2)
mytable[i,4]<-round(median(dta1971$muslims_percent[dta1971$State_name_1976==states[i] & !is.na(dta1971$muslims_percent)]),2)
mytable[i,5]<-round(mean(dta1971$muslims_percent[dta1971$State_name_1976==states[i] & !is.na(dta1971$muslims_percent)]),2)
}

row.names(mytable)<-states
colnames(mytable)<-c("N", "Min", "Max", "Median", "Mean")

#Table in Latex format
xtable(mytable)


####Figure 2 -- percentage of Muslims in general and SC-reserved constituencies 

pdf("Replication_Figure2.pdf", width=10, height=5.5)
par(mfrow=c(1,2))

plot(dta1971$muslims_percent[dta1971$AC_type_noST=="GEN"]~dta1971$SC_percent[dta1971$AC_type_noST=="GEN"], las=1, pch=19, cex=.15, xlim=c(0,100), ylim=c(0,100), xlab="Percentage of SCs", ylab="Percentage of Muslims", main="General constituencies (N=2493)")
lines(x=c(0,100), y=c(0,100))
text(x=50, y=80, "More Muslims than \n SCs in constituency")
text(x=80, y=50, "More SCs than \n Muslims")
par(new=TRUE)
plot(dta1971$muslims_percent[dta1971$AC_type_noST=="GEN" & dta1971$State_no_2001_old==9 & (dta1971$AC_number_1976 %in% c(262, 264, 217, 86, 81, 84, 141, 100, 331))]~dta1971$SC_percent[dta1971$AC_type_noST=="GEN" & dta1971$State_no_2001_old==9 & (dta1971$AC_number_1976 %in% c(262, 264, 217, 86, 81, 84, 141, 100, 331))], xlim=c(0,100), ylim=c(0,100), xlab="", ylab="", main="", col="red", axes=FALSE)
legend("topleft", "Examples in \nSachar report", col="red", pch=1)

##Looking at whether there are more Muslims than SCs in constituencies
plot(dta1971$muslims_percent[dta1971$AC_type_noST=="SC"]~dta1971$SC_percent[dta1971$AC_type_noST=="SC"], pch=19, cex=.15, xlim=c(0,100), ylim=c(0,100), xlab="Percentage of SCs", ylab="Percentage of Muslims", main="Constituencies reserved for SC (N=489)", las=1)
lines(x=c(0,100), y=c(0,100))
text(x=50, y=80, "More Muslims than \n SCs in constituency")
text(x=80, y=50, "More SCs than \n Muslims")
par(new=TRUE)
plot(dta1971$muslims_percent[dta1971$AC_type_noST=="SC" & dta1971$State_no_2001_old==9 & (dta1971$AC_number_1976 %in% c(391, 21, 20, 374, 177, 159, 406, 50))]~dta1971$SC_percent[dta1971$AC_type_noST=="SC" & dta1971$State_no_2001_old==9 & (dta1971$AC_number_1976 %in% c(391, 21, 20, 374, 177, 159, 406, 50))], xlim=c(0,100), ylim=c(0,100), xlab="", ylab="", main="", col="red", axes=FALSE)
legend("topleft", "Examples in \nSachar report", col="red", pch=1)
dev.off()


####Figure 3 -- percentage Muslims out of total and only non-SC population

pdf("Replication_Figure3.pdf", width=9, height=5)
par(mar = c(2.5, 2.5, 4, .5))
par(mfrow=c(1,2))
boxplot(dta1971$muslims_percent~dta1971$AC_type_noST, main="Percentage of Muslims (whole population)", boxwex=.5,names=c("General cons.", "Reserved for SC"), las=1)
boxplot(dta1971$muslims_percent_non_SC~dta1971$AC_type_noST, main="Percentage of Muslims (non-SC population)", boxwex=.5, names=c("General cons.", "Reserved for SC"), las=1)
dev.off()

####Figure 4 -- percentage of Muslims in general and SC-reserved constituencies by state

p.value_format<-function(my_test, my_digits){
strings<-rep(NA,length(my_test) )
for (i in 1:length(my_test)){
if (my_test[i]<0.01) {
strings[i]<-	"p<0.01"} else {
strings[i]<-paste("p=", format(my_test[i], nsmall=my_digits, digits=my_digits-1), sep="")
}	
}
return(strings)
}

mymatrix<-as.data.frame(matrix(nrow=length(states), ncol=10))
for (i in 1:length(states)){
mymatrix[i,1]<-mean(dta1971$muslims_percent[dta1971$State_name_1976==states[i] & !is.na(dta1971$muslims_percent) & dta1971$AC_type_noST =="GEN"])
mymatrix[i,2]<-min(dta1971$muslims_percent[dta1971$State_name_1976==states[i] & !is.na(dta1971$muslims_percent) & dta1971$AC_type_noST =="GEN"])
mymatrix[i,3]<-max(dta1971$muslims_percent[dta1971$State_name_1976==states[i] & !is.na(dta1971$muslims_percent) & dta1971$AC_type_noST =="GEN"])
mymatrix[i,4]<-mean(dta1971$muslims_percent[dta1971$State_name_1976==states[i] & !is.na(dta1971$muslims_percent) & dta1971$AC_type_noST =="SC"])
mymatrix[i,5]<-min(dta1971$muslims_percent[dta1971$State_name_1976==states[i] & !is.na(dta1971$muslims_percent) & dta1971$AC_type_noST =="SC"])
mymatrix[i,6]<-max(dta1971$muslims_percent[dta1971$State_name_1976==states[i] & !is.na(dta1971$muslims_percent) & dta1971$AC_type_noST =="SC"])
mytest<-t.test(dta1971$muslims_percent[dta1971$State_name_1976==states[i] & !is.na(dta1971$muslims_percent)]~dta1971$AC_type_noST[dta1971$State_name_1976==states[i] & !is.na(dta1971$muslims_percent)])
mymatrix[i,7]<-mytest$estimate[1]-mytest$estimate[2]
mymatrix[i,8]<-mytest$conf.int[1]
mymatrix[i,9]<-mytest$conf.int[2]
mymatrix[i,10]<-mytest$p.value
}
row.names(mymatrix)<-states

mymatrix<-mymatrix[order(row.names(mymatrix), decreasing=T),]

pdf("Replication_Figure4.pdf")
par(mar = c(4, 8.5, 1, .5))

plot(x=NULL,axes=F, xlim=c(0, 100), ylim=c(1,14),xlab="Percentage of Muslims", ylab="", cex.main=2)
  # add the 0, 0.05 vertical lines
axis(side=1,tick=TRUE, las=1, cex.axis=1)
axis(side=2,at=c(1:14), labels=row.names(mymatrix), cex.axis=1, las=1, tick=F)

for (i in 1:nrow(mymatrix)) {
arrows(x0=mymatrix[i,2], x1=mymatrix[i,3], y0=(i+.15), y1=(i+.15), angle=90, length=.025, code=3)
arrows(x0=mymatrix[i,5], x1=mymatrix[i,6], y0=(i-.15), y1=(i-.15), angle=90, length=.025, code=3, col="gray40")
points(x=as.numeric(mymatrix[i,1]), y=i+.15, pch=16, cex=.7)
points(x=as.numeric(mymatrix[i,4]), y=i-.15, pch=25, cex=.7,  fill="gray40")
text(x=95, y=i, p.value_format(mymatrix[i,10], 2), cex=.8)
}
legend(x=50, y=7, pch=c(16, NA, 25, NA), lty=c(NA, 1, NA, 1), col=c(1, 1, 1, "gray40"), legend=c("Mean general", "Min-Max general", "Mean reserved", "Min-Max reserved"), cex=.9, bg="white", merge=T)
dev.off()


####Table 2 -- output from matching models

Tr<-ifelse(dta1971$AC_type_noST=="SC", 1, 0)

X<-as.data.frame(cbind(as.numeric(dta1971$State_no_2001_old), as.numeric(dta1971$DELIM_district_no), dta1971$SC_percent_true))

Matched<-Match(Y=dta1971$muslims_percent, Tr=Tr, X=X, estimand="ATT", exact=c(TRUE, TRUE, FALSE), replace=FALSE)

sd(dta1971$SC_percent_true)*.05721

#Max distance is .5 percentage point
Matched_cal<-Match(Y=dta1971$muslims_percent, Tr=Tr, X=X, estimand="ATT", exact=c(TRUE, TRUE, FALSE), replace=FALSE, caliper=c(0,0, .05721))

my_t<-t.test(dta1971$muslims_percent~dta1971$AC_type_noST)
my_t_SC<-t.test(dta1971$SC_percent_true~dta1971$AC_type_noST)
my_t_SC_matched<-t.test(dta1971$SC_percent_true[Matched$index.control], dta1971$SC_percent_true[Matched$index.treated])
my_t_SC_matched_cal<-t.test(dta1971$SC_percent_true[Matched_cal$index.control], dta1971$SC_percent_true[Matched_cal$index.treated])

outputTable <- function(x){
  cat("\\begin{table}[ht] \n")
  cat("\\caption{Output from matching models} \n")
  cat(" \\begin{tabular}{lrrr} \\hline \\hline \n")
  cat("& Full data & Matched data & Matched with caliper \\\\ \\hline \n",sep="")

#Line for Muslims in gen cons
  cat("Muslims in general cons. &",
    round(my_t$est[1], 1), "&", 
   round(mean(dta1971$muslims_percent[Matched$index.control]), 2),  "&", 
    round(mean(dta1971$muslims_percent[Matched_cal$index.control]), 2), "\\", "\\", "\n",
      sep="")
#Line for Muslims in sc cons
  cat("Muslims in reserved cons. &",
    round(my_t$est[2], 1), "&", 
   round(mean(dta1971$muslims_percent[Matched$index.treated]), 2),  "&", 
    round(mean(dta1971$muslims_percent[Matched_cal$index.treated]), 2), "\\", "\\", "\n",
      sep="")
#Line diff in Muslims
cat("Difference in means &",
round(my_t$est[2]-my_t$est[1], 2), "&", 
round(Matched$est, 2), "&", 
round(Matched_cal$est, 2), "\\", "\\", "\n",
      sep="")

#LIne for p-value of diff in Muslims
cat("P-value &",
round(my_t$p.value, 3), "&", 
format.pval((1 - pnorm(abs(Matched$est/Matched$se.standard))) * 2, digits = 2), "&", 
format.pval((1 - pnorm(abs(Matched_cal$est/Matched_cal$se.standard))) * 2, digits = 2), "\\", "\\", " \\hline", "\n",
      sep="")
      
  cat("&&&\\\\\n")

#########ADD IN VALUES FOR SCs
#Line for SCs in gen cons
  cat("SCs in general cons. &",
    round(my_t_SC$est[1], 1), "&", 
   round(mean(dta1971$SC_percent_true[Matched$index.control]), 1),  "&", 
    round(mean(dta1971$SC_percent_true[Matched_cal$index.control]), 1), "\\", "\\", "\n",
      sep="")
#Line for SCs in sc cons
  cat("SCs in reserved cons. &",
    round(my_t_SC$est[2], 1), "&", 
   round(mean(dta1971$SC_percent_true[Matched$index.treated]), 1),  "&", 
    round(mean(dta1971$SC_percent_true[Matched_cal$index.treated]), 1), "\\", "\\", "\n",
      sep="")
#Line diff in SCs
cat("Difference in means &",
round(my_t_SC$est[2]-my_t_SC$est[1], 2), "&", 
round(my_t_SC_matched$est[2]-my_t_SC_matched$est[1], 2), "&", 
round(my_t_SC_matched_cal$est[2]-my_t_SC_matched_cal$est[1], 2), "\\", "\\", "\n",
      sep="")

#LIne for p-value of diff in Muslims
cat("P-value &",
round(my_t_SC$p.value, 3), "&", 
round(my_t_SC_matched$p.value, 3), "&", 
round(my_t_SC_matched_cal$p.value, 3), "\\", "\\", "\\hline", "\n",
      sep="")
      
 cat("&&&\\\\ \n")

#########ADD IN SAMPLE SIZE
cat("Number of general cons.", "&", 
round(table(dta1971$AC_type_noST)[1]), "&", 
round(table(dta1971$AC_type_noST[Matched$index.control])), "&", 
round(table(dta1971$AC_type_noST[Matched_cal$index.control])), "\\", "\\", "\n",
      sep="")

cat("Number of SC cons.", "&", 
round(table(dta1971$AC_type_noST)[2]), "&", 
round(table(dta1971$AC_type_noST[Matched$index.treated])), "&", 
round(table(dta1971$AC_type_noST[Matched_cal$index.treated])), "\\", "\\", "\\hline", "\n",
      sep="") 
cat("\\end{tabular} \\end{table} \n")
}

#Table in Latex format
outputTable(x)
